########
Modules
########

..
    to document functions, add them to __all__ in ../sarwaveifrproc/__init__.py

.. automodule:: sarwaveifrproc
    :members:


.. automodule:: sarwaveifrproc.utils
    :members:

.. automodule:: sarwaveifrproc.l2_wave
     :members:

.. automodule:: sarwaveifrproc.main
     :members:
